<template>
  <el-card
    style="border-radius: 0"
    :body-style="{ padding: '1rem 2rem' }"
    v-loading="loading"
  >
    <template #header>
      <div
        style="
          font-weight: bold;
          font-size: 1.2rem;
          height: 2rem;
          line-height: 2rem;
        "
      >
        成品当月数据统计 &nbsp; &nbsp;
        <el-button @click="refresh" type="success">刷新</el-button>
      </div>
    </template>
    <div style="display: flex; justify-content: space-between">
      <div ref="operationDom" style="height: 25rem; width: 100%"></div>
    </div>
  </el-card>
</template>

<script setup>
import { ref, onMounted, onUnmounted, nextTick } from "vue";
// 引入echarts
import * as echarts from "echarts";
import dayjs from "dayjs";
import { ElLoading } from "element-plus";
import http from "@/../src/api/http.js";
const loading = ref(true);
// 创建一个响应式引用来保存DOM元素
const operationDom = ref(null);
let operationChartInstance = null;
let infoChartInstance = null;
const infoDom = ref(null);
const xData = ref([]);
const yData = ref([]);
const refresh =  () => {
  const url = "api/ProInStatistics/GetMonthProductions";
  http.post(url, {}, true).then((result) => {
    loading.value = true;
    operationChartInstance = echarts.init(operationDom.value);
  // infoChartInstance=echarts.init(infoDom.value)
  let dateList = [
    ["2025-5-1", 0],
    ["2025-5-2", 0],
    ["2025-5-3", 0],
    ["2025-5-4", 0],
    ["2025-5-5", 0],
    ["2025-5-6", 0],
    ["2025-5-7", 10050],
    ["2025-5-8", 30000],
    ["2025-5-9", 300000],
    ["2025-5-10", 0],
    ["2025-5-11", 0],
    ["2025-5-12", 0],
    ["2025-5-13", 0],
    ["2025-5-14", 0],
    ["2025-5-15", 0],
    ["2025-5-16", 0],
    ["2025-5-17", 0],
    ["2025-5-18", 0],
    ["2025-5-19", 0],
    ["2025-5-20", 0],
    ["2025-5-21", 0],
    ["2025-5-22", 0],
    ["2025-5-23", 0],
    ["2025-5-24", 0],
    ["2025-5-25", 0],
    ["2025-5-26", 0],
    ["2025-5-27", 0],
    ["2025-5-28", 0],
    ["2025-5-29", 0],
    ["2025-5-30", 0],
    ["2025-5-31", 0],
  ];
  dateList=[];
  const data = result.data;
    data.forEach((item) => {
      dateList.push([item.dateNow, item.dayProDuctions]);
    });
  console.log(dateList);
  const heatmapData = [];
  const lunarData = [];
  for (let i = 0; i < dateList.length; i++) {
    heatmapData.push([dateList[i][0], Math.random() * 300]);
    lunarData.push([dateList[i][0], 1, dateList[i][1], dateList[i][2]]);
  }
  let chartData = [];
  dateList.forEach((item) => {
    chartData.push({
      value: [item[0], item[1]],
      itemStyle:
        item[0] === dayjs().format('YYYY-MM-DD')
          ? {
              borderColor: "red",
            }
          : {}, //当前日期标注边框为红色
      symbol: "rect", // 核心1，长方形来填充
    });
  });
  var option = {
    // tooltip: {
    //   formatter: function (params) {
    //     return '降雨量: ' + params.value[1].toFixed(2);
    //   }
    // },

    visualMap: {
      show: false,
      min: 0,
      max: 300,
      calculable: true,
      seriesIndex: [2],
      orient: "horizontal",
      left: "center",
      bottom: 20,
      inRange: {
        color: ["#e0ffff", "#006edd"],
        opacity: 0.3,
      },
      controller: {
        inRange: {
          opacity: 0.5,
        },
      },
    },
    calendar: {
      left: "center",
      top: 49,
      cellSize: [70, 70],
      orient: "vertical",
      dayLabel: {
        firstDay: 1,
        nameMap: "cn",
      },
      monthLabel: {
        formatter: "{M}月",
      },
      range: "2025-05",
      yearLabel: {
        show: false,
      },
    },
    series: [
      {
        type: "scatter",
        coordinateSystem: "calendar",
        symbolSize(params) {
          //核心2
          if (params[0] === dayjs().format('YYYY-MM-DD')) {
            return 70; //当前日期高亮 宽度高度设置成和单元格宽度高度一样
          } else {
            return 1;
          }
        },
        label: {
          show: true,
          formatter: function (params) {
            var d = echarts.number.parseDate(params.value[0]);
            if (params.value[0] === dayjs().format('YYYY-MM-DD')) {
              return d.getDate() + "\n\n当日入仓量\n\n";
            }
            return d.getDate() + "\n\n入仓量\n\n";
          },
          color: "#000",
        },
        data: chartData,
        silent: true,
      },
      {
        type: "scatter",
        coordinateSystem: "calendar",
        symbolSize: 0,
        label: {
          show: true,
          formatter: function (params) {
            return (
              "\n\n\n" +
              (params.value[1] && params.value[1] != undefined
                ? params.value[1] + "㎡"
                : "0㎡")
            );
          },
          fontSize: 14,
          fontWeight: 700,
          color: "#a00",
        },
        data: chartData,
        silent: true,
      },
      // {
      //   type: 'scatter',
      //   coordinateSystem: 'calendar',
      //   symbolSize: 0,
      //   label: {
      //     show: true,
      //     formatter: function (params) {
      //       return '\n\n\n' + (params.value[3]?params.value[3]+'㎡' : '');
      //     },
      //     fontSize: 14,
      //     fontWeight: 700,
      //     color: '#a00'
      //   },
      //   data: lunarData,
      //   silent: true
      // },
    ],
  };
  operationChartInstance.setOption(option);
  // infoChartInstance.setOption(option);
  nextTick(() => {
    loading.value = false;
  });
    
  });
  
};
// 初始化ECharts实例并设置配置项（这里以折线图为例，但可灵活替换）
onMounted(async () => {
  await nextTick(); // 确保DOM已经渲染完成
  const url = "api/ProInStatistics/GetMonthProductions";
  http.post(url, {}, true).then((result) => {
  operationChartInstance = echarts.init(operationDom.value);
  // infoChartInstance=echartss.init(infoDom.value)
  let dateList = [
    ["2025-5-1", 0],
    ["2025-5-2", 0],
    ["2025-5-3", 0],
    ["2025-5-4", 0],
    ["2025-5-5", 0],
    ["2025-5-6", 0],
    ["2025-5-7", 10050],
    ["2025-5-8", 30000],
    ["2025-5-9", 300000],
    ["2025-5-10", 0],
    ["2025-5-11", 0],
    ["2025-5-12", 0],
    ["2025-5-13", 0],
    ["2025-5-14", 0],
    ["2025-5-15", 0],
    ["2025-5-16", 0],
    ["2025-5-17", 0],
    ["2025-5-18", 0],
    ["2025-5-19", 0],
    ["2025-5-20", 0],
    ["2025-5-21", 0],
    ["2025-5-22", 0],
    ["2025-5-23", 0],
    ["2025-5-24", 0],
    ["2025-5-25", 0],
    ["2025-5-26", 0],
    ["2025-5-27", 0],
    ["2025-5-28", 0],
    ["2025-5-29", 0],
    ["2025-5-30", 0],
    ["2025-5-31", 0],
  ];
  dateList=[];
  const data = result.data;
    data.forEach((item) => {
      dateList.push([item.dateNow, item.dayProDuctions]);
    });
  console.log(dateList);
  const heatmapData = [];
  const lunarData = [];
  for (let i = 0; i < dateList.length; i++) {
    heatmapData.push([dateList[i][0], Math.random() * 300]);
    lunarData.push([dateList[i][0], 1, dateList[i][1], dateList[i][2]]);
  }
  let chartData = [];
  dateList.forEach((item) => {
    chartData.push({
      value: [item[0], item[1]],
      itemStyle:
        item[0] === dayjs().format('YYYY-MM-DD')
          ? {
              borderColor: "red",
            }
          : {}, //当前日期标注边框为红色
      symbol: "rect", // 核心1，长方形来填充
    });
  });
  var option = {
    // tooltip: {
    //   formatter: function (params) {
    //     return '降雨量: ' + params.value[1].toFixed(2);
    //   }
    // },

    visualMap: {
      show: false,
      min: 0,
      max: 300,
      calculable: true,
      seriesIndex: [2],
      orient: "horizontal",
      left: "center",
      bottom: 20,
      inRange: {
        color: ["#e0ffff", "#006edd"],
        opacity: 0.3,
      },
      controller: {
        inRange: {
          opacity: 0.5,
        },
      },
    },
    calendar: {
      left: "center",
      top: 49,
      cellSize: [70, 70],
      orient: "vertical",
      dayLabel: {
        firstDay: 1,
        nameMap: "cn",
      },
      monthLabel: {
        formatter: "{M}月",
      },
      range: "2025-05",
      yearLabel: {
        show: false,
      },
    },
    series: [
      {
        type: "scatter",
        coordinateSystem: "calendar",
        symbolSize(params) {
          //核心2
          if (params[0] === dayjs().format('YYYY-MM-DD')) {
            return 70; //当前日期高亮 宽度高度设置成和单元格宽度高度一样
          } else {
            return 1;
          }
        },
        label: {
          show: true,
          formatter: function (params) {
            var d = echarts.number.parseDate(params.value[0]);
            if (params.value[0] === dayjs().format('YYYY-MM-DD')) {
              return d.getDate() + "\n\n当日入仓量\n\n";
            }
            return d.getDate() + "\n\n入仓量\n\n";
          },
          color: "#000",
        },
        data: chartData,
        silent: true,
      },
      {
        type: "scatter",
        coordinateSystem: "calendar",
        symbolSize: 0,
        label: {
          show: true,
          formatter: function (params) {
            return (
              "\n\n\n" +
              (params.value[1] && params.value[1] != undefined
                ? params.value[1] + "㎡"
                : "0㎡")
            );
          },
          fontSize: 14,
          fontWeight: 700,
          color: "#a00",
        },
        data: chartData,
        silent: true,
      },
      // {
      //   type: 'scatter',
      //   coordinateSystem: 'calendar',
      //   symbolSize: 0,
      //   label: {
      //     show: true,
      //     formatter: function (params) {
      //       return '\n\n\n' + (params.value[3]?params.value[3]+'㎡' : '');
      //     },
      //     fontSize: 14,
      //     fontWeight: 700,
      //     color: '#a00'
      //   },
      //   data: lunarData,
      //   silent: true
      // },
    ],
  };
  operationChartInstance.setOption(option);
});
  // infoChartInstance.setOption(option);
  nextTick(() => {
    loading.value = false;
  });
});

// 销毁ECharts实例
onUnmounted(() => {
  if (operationChartInstance != null && operationChartInstance.dispose) {
    operationChartInstance.dispose();
  }
});

//窗口大小变化重绘echart
window.onresize = function () {
  if (operationChartInstance != null && operationChartInstance.resize) {
    operationChartInstance.resize();
  }
};
</script>

<style></style>